# -*- coding: utf-8 -*-
"""All the forms used in the project"""

from tw.forms import (TableForm, ListForm, Form, Spacer, TextField, TextArea, 
    CheckBox, MultipleSelectField, Label, SingleSelectField)
from tw.forms.validators import Int, NotEmpty, UnicodeString, URL, \
    StringBoolean, Bool, All, Regex, Email

from mirrormanager import model
from mirrormanager.model import *

class HostCategoryUrlForm(ListForm):
    show_errors = True

    fields = [
        TextField("url", validator=UnicodeString(not_empty=True),
            attrs=dict(size='30')),
        CheckBox("private", default=False,
            label_text="For other mirrors only")
    ]


class ConfirmDeleteForm(ListForm):
    fields=[
    ]


class CountryContinentRedirectForm(ListForm):
    fields = [
        TextField("country", validator=UnicodeString(not_empty=True)),
        TextField("continent", validator=UnicodeString(not_empty=True)),
    ]


class LabelObjName(Label):
    template = """
    <label xmlns:py="http://purl.org/kid/ns#"
    id="${field_id}"
    class="${field_class}"
    py:if="value is not None"
    py:content="value.name"
    />
    """

class HostCategoryFormNew(ListForm):
    def get_category_options():
        return [(c.id, c.name) for c in model.DBSession.query(Category).order_by("name").all()]
    
    help_text = 'e.g. rsync://download.fedora.redhat.com/fedora-linux-core'
    #help_text += config.get('mirrormanager.upstream', 'rsync://download.fedora.redhat.com/fedora-linux-core')
    fields = [
        SingleSelectField("category", options=get_category_options,
                                         validator=NotEmpty()),
        CheckBox("admin_active", default=True, validator=Bool()),
        CheckBox("user_active", default=True, validator=Bool()),
        TextField("upstream", attrs=dict(size='30'), 
            validator=UnicodeString(), help_text=help_text),
        CheckBox("always_up2date", default=False, validator=Bool(),
            help_text="Set to force belief that the whole category is always in sync.  Be careful with this.")
    ]

class HostCategoryFormRead(ListForm):
    help_text = 'e.g. rsync://download.fedora.redhat.com/fedora-linux-core'
    #help_text += config.get('mirrormanager.upstream', 'rsync://download.fedora.redhat.com/fedora-linux-core')
    fields = [
        LabelObjName("category"),
        CheckBox("admin_active", default=True, validator=Bool()),
        CheckBox("user_active", default=True, validator=Bool()),
        TextField("upstream", attrs=dict(size='30'), 
            validator=UnicodeString(), help_text=help_text),
        CheckBox("always_up2date", default=False, validator=Bool(),
            help_text="Set to force belief that the whole category is always in sync.  Be careful with this.")
    ]


class RepositoryForm(ListForm):
    fields = [
        TextField("name", validator=UnicodeString(not_empty=True),
            attrs=dict(size='30')),
        TextField("prefix", validator=UnicodeString(not_empty=True),
            attrs=dict(size='30')),
        LabelObjName("category"),
        LabelObjName("version"),
        LabelObjName("arch"),
        LabelObjName("directory")
    ]


class RepositoryRedirectForm(ListForm):
    fields = [
        TextField("fromRepo", validator=UnicodeString(not_empty=True)),
        TextField("toRepo", validator=UnicodeString(not_empty=True)),
    ]


class VersionForm(ListForm):
    def get_products_options():
        return [(p.id, p.name) for p in model.DBSession.query(Product).order_by("name").all()]

    fields = [
        SingleSelectField("product", options=get_products_options,
            validator=NotEmpty()),
        TextField("name", validator=UnicodeString(), attrs=dict(size='30')),
        CheckBox("isTest", validator=Bool(), label="is a Test release"),
        CheckBox("display", validator=Bool(),
            label="display in the publiclist chooser", default=True),
        TextField("display_name", validator=UnicodeString(),
            attrs=dict(size='30'), help_text="Name displayed to users (optional)" ),
    ]


class HostCategoryUrlForm(ListForm):
    fields = [
        TextField("url", validator=UnicodeString(), attrs=dict(size='30')),
        CheckBox("private", validator=Bool(),
            default=False, label_text="For other mirrors only")
    ]



class HostNetblockForm(ListForm):
    fields = [
        TextField("netblock", validator=UnicodeString(not_empty=True)),
    ]


class HostAclIPForm(ListForm):
    fields = [
        TextField("ip", label_text="IP", 
            validator=UnicodeString(not_empty=True)),
    ]


class HostCountryAllowedForm(ListForm):
    fields = [
        TextField("country", validator=Regex(r'^[a-zA-Z][a-zA-Z]$'),
            help_text="2-letter ISO country code"),
    ]


class ProductForm(ListForm):
    fields = [
        TextField("name", validator=UnicodeString(not_empty=True),
            attrs=dict(size='30')),
    ]

class EmbargoedCountryForm(ListForm):
    fields = [
        TextField("country_code", 
            validator=Regex(r'^[a-zA-Z][a-zA-Z]$'),
            help_text="2-letter ISO country code" ),
    ]


class ArchForm(ListForm):
    fields = [
        TextField("name", validator=UnicodeString(), attrs=dict(size='30')),
    ]


class SiteAdminForm(ListForm):

    fields = [
        TextField("username", validator=UnicodeString(not_empty=True),
            help_text="FAS username you wish to have be an admin for this site"
            ),
    ]


class SiteToSiteForm(TableForm):
    def get_sites_options():
        return [(s.id, s.name) 
            for s in model.DBSession.query(Site).order_by('name').all()]

    fields = [
        MultipleSelectField("sites", options=get_sites_options, size=15,
                            validator=UnicodeString(not_empty=True),
                            label_text="Sites")
            ]


class HostForm(TableForm):
    fields = [
        TextField('name', validator=UnicodeString(not_empty=True),
            attrs=dict(size='30'), label_text="Host Name",
            help_text="* Name of server as seen by a public end user"),
        CheckBox("admin_active", default=True, validator=Bool(),
            help_text="Uncheck this box to temporarily disable this host, it will be removed from public listings."),
        CheckBox("user_active", default=True, validator=Bool(),
            help_text="Uncheck this box to temporarily disable this host, it will be removed from public listings."),
        TextField("country", validator=Regex(r'^[a-zA-Z][a-zA-Z]$', not_empty=True),
            help_text="2-letter ISO country code" ),
        TextField("bandwidth_int", validator=Int(),
            help_text="* integer megabits/sec, how much bandwidth this host can serve"),
        CheckBox("private", validator=Bool(),
            help_text="e.g. not available to the public, an internal private mirror"),
        CheckBox("internet2",validator=Bool(),
            help_text="on Internet2"),
        CheckBox("internet2_clients", 
            help_text="serves Internet2 clients, even if private"),
        TextField("asn", label="ASN", default='',  validator=Int, 
            help_text="Autonomous System Number, used in BGP routing tables."),
        CheckBox('asn_clients', label="ASN Clients?", default=True, 
            help_text="Serve all clients from the same ASN.  Used for ISPs, companies, or schools, not personal networks."),
        TextField("robot_email", validator=All(UnicodeString, Email),
            help_text="email address, will receive notice of upstream content updates"),
        TextField("comment", validator=UnicodeString(),
            help_text="text, anything else you'd like a public end user to know about your mirror")
    ]

class SiteForm(TableForm):

    #template = "mirrormanager.templates.site"
    show_errors = True

    fields = [
        TextField("name", validator=UnicodeString(not_empty=True),
            label_text="Site Name",
            help_text=""),
        TextField("password", validator=UnicodeString(not_empty=True),
            label_text="Site Password",
            help_text="used by report_mirrors script, you make this anything you want"),
        TextField("orgUrl", validator=URL(not_empty=True),
            attrs=dict(size='30'), 
            label_text="Organization URL",
            help_text="Company/School/Organization URL e.g. http://www.redhat.com"),
        CheckBox("private", default=False, validator=Bool(),
            help_text="e.g. Not available to the public"),
        CheckBox("admin_active", default=True, validator=Bool(),
            help_text="Uncheck this box to temporarily disable this site, it will be removed from public listings."),
        CheckBox("user_active", default=True, validator=Bool(),
            help_text="Uncheck this box to temporarily disable this site, it will be removed from public listings."),
        CheckBox("allSitesCanPullFromMe", default=False, validator=Bool(),
            label_text="All sites can pull from me?",
            help_text="Enable all mirror sites to pull from me without explicitly adding them to my list."),
        TextArea("downstreamComments", validator=UnicodeString(),
            attrs=dict(rows=5, cols=60),
            label_text="Comments for downstream siteadmins."),
        Spacer()]

    submit_text = 'Save site'
